package com.ruoyi.bst.areaSub.utils;

import java.math.BigDecimal;
import java.util.List;

import org.locationtech.jts.geom.Geometry;

import com.ruoyi.bst.areaSub.domain.AreaSubVO;
import com.ruoyi.common.utils.collection.CollectionUtils;
import com.ruoyi.common.utils.map.GeoUtils;

import lombok.extern.slf4j.Slf4j;

@Slf4j
public class AreaSubUtil {

    /**
     * 获取定位所在的区域
     * @param areaSubList 区域列表
     * @param longitude 经度
     * @param latitude 纬度
     * @param areaError 运营区误差
     * @return 最近的区域
     */
    public static AreaSubVO getInAreaSub(List<AreaSubVO> areaSubList, BigDecimal longitude, BigDecimal latitude, BigDecimal areaError) {
        if (CollectionUtils.isEmptyElement(areaSubList)) {
            return null;
        }
        double tolerance = 0; // 误差距离
        if (areaError != null) {
            tolerance = areaError.doubleValue();
        }
        for (AreaSubVO area : areaSubList) {
            Geometry geometry = GeoUtils.fromWkt(area.getBoundary());
            if (geometry == null) {
                continue;
            }
            if(area.getError() != null ){
                tolerance = area.getError().doubleValue();
            }
//            log.debug(" ---- 区域{} ---- 定位 {},{} ----",area.getName(), longitude, latitude);
            boolean inCircle = GeoUtils.isInPolygonWithTolerance(longitude, latitude, geometry, tolerance);
            if (inCircle) {
                return area;
            }
        }
        return null;
    }

}
